//
//  ViewController.swift
//  SparkleClock
//
//  Created by Aaron Douglas on 12/5/14.
//  Copyright (c) 2014 Razeware. All rights reserved.
//

import UIKit
import QuartzCore

class ViewController: UIViewController {
  var timer: NSTimer!
  var dateFormatter: NSDateFormatter!
  @IBOutlet var clockLabel: UILabel!
  @IBOutlet var tapGestureRecognizer: UITapGestureRecognizer!
  @IBOutlet var shimmeringView: FBShimmeringView!
  
  override func viewDidLoad() {
    super.viewDidLoad()
    
    timer = NSTimer.scheduledTimerWithTimeInterval(0.5, target: self, selector: Selector("updateClock"), userInfo: nil, repeats: true)
    dateFormatter = NSDateFormatter()
    dateFormatter.dateStyle = NSDateFormatterStyle.NoStyle
    dateFormatter.timeStyle = NSDateFormatterStyle.MediumStyle
    shimmeringView.contentView = clockLabel
    shimmeringView.shimmering = true
    
    //Optional ShimmeringView protocal values
    //All values show are the defaults
    shimmeringView.shimmeringPauseDuration = 0.4
    shimmeringView.shimmeringAnimationOpacity = 0.5
    shimmeringView.shimmeringOpacity = 1.0
    shimmeringView.shimmeringSpeed = 230
    shimmeringView.shimmeringHighlightLength = 1.0
    shimmeringView.shimmeringDirection = FBShimmerDirection.Right
    
    //All possible directional values
    //FBShimmerDirection.Right,  Shimmer animation goes from left to right
    //FBShimmerDirection.Left,  Shimmer animation goes from right to left
    //FBShimmerDirection.Up,  Shimmer animation goes from below to above
    //FBShimmerDirection.Down,  Shimmer animation goes from above to below
    
    shimmeringView.shimmeringBeginFadeDuration = 0.1
    shimmeringView.shimmeringEndFadeDuration = 0.3
  }
  
  override func viewWillAppear(animated: Bool) {
    updateClock()
  }
  
  override func viewDidAppear(animated: Bool) {
    super.viewDidAppear(animated)
    
    UIApplication.sharedApplication().idleTimerDisabled = true
  }
  
  override func viewDidDisappear(animated: Bool) {
    super.viewDidDisappear(animated)
    
    UIApplication.sharedApplication().idleTimerDisabled = false
  }
  
  override func prefersStatusBarHidden() -> Bool {
    return true
  }
  
  func updateClock() {
    var timeToDisplay = dateFormatter.stringFromDate(NSDate())
    clockLabel.text = timeToDisplay
  }
  
  @IBAction func didTapView() {
    tapGestureRecognizer.enabled = false
    shimmeringView.shimmering = !shimmeringView.shimmering
    
    UIView.animateWithDuration(0.25, delay: 0, usingSpringWithDamping: 0.5, initialSpringVelocity: 0, options: .CurveEaseIn, animations: {
      self.clockLabel.transform = CGAffineTransformMakeScale(1.2, 1.2)
      }, completion: { (finished) -> Void in
        UIView.animateWithDuration(0.25, delay: 0.1, usingSpringWithDamping: 0.5, initialSpringVelocity: 0, options: .CurveEaseOut, animations: {
          self.clockLabel.transform = CGAffineTransformIdentity
          }, completion: {
            (finished) -> Void in
            self.tapGestureRecognizer.enabled = true
        })
    })
  }
}

